==> MediaWikiLanguageExtensionBundle-2016.01.tar.bz2: extensions/cldr/CldrNames/CldrNamesLrc.php <==
<?php

$languageNames = array(
	'ab' => 'آذأربایئجانی',
	'af' => 'آفریکانس',
	'agq' => 'آقئم',
	'ak' => 'آکان',
	'am' => 'أمھأری',
	'ar' => 'أرأڤی',
	'ar-001' => 'عروی مدرن',
	'arn' => 'ماپوٙچئ',
	'as' => 'آسامی',
	'asa' => 'آسوٙ',
	'az' => 'آذأربایئجانی ھارگە',
	'az-arab' => 'آذأری ھارگە',
	'ba' => 'باشکیری',
	'be' => 'بئلاروٙسی',
	'bem' => 'بیما',
	'bez' => 'بئنا',
	'bg' => 'بولغاری',
	'bgn' => 'بألوٙچی أقتوٙنئشین',
	'bm' => 'بامبارا',
	'bn' => 'بأنگالی',
	'bo' => 'تأبأتی',
	'br' => 'بئرئتون',
	'brx' => 'بودو',
	'bs' => 'بوسنیایی',
	'ca' => 'کاتالان',
	'ce' => 'چئچئنی',
	'cgg' => 'چیگا',
	'chr' => 'چوروٙکی',
	'ckb' => 'کوردی سوٙرانی',
	'co' => 'کوریسکان',
	'cv' => 'چواشی',
	'cy' => 'ڤئلزی',
	'da' => 'دانمارکی',
	'dav' => 'تایتا',
	'de' => 'آلمانی',
	'de-at' => 'آلمانی ئوتریشی',
	'de-ch' => 'آلمانی سوٙییسی',
	'dje' => 'زارما',
	'dsb' => 'سوربی ھاری',
	'dua' => 'دوٙالا',
	'dyo' => 'جولا فوٙنیی',
	'dz' => 'زوٙنگخا',
	'ebu' => 'ئمبو',
	'ee' => 'ئڤئ',
	'el' => 'یوٙنانی',
	'en' => 'ئینگیلیسی',
	'en-au' => 'ئینگیلیسی ئوستارالیایی',
	'en-ca' => 'ئینگیلیسی کانادایی',
	'en-gb' => 'ئینگیلیسی بئریتانیایی',
	'en-us' => 'ئینگیلیسی ئمریکایی',
	'eo' => 'ئسپئرانتو',
	'es' => 'ئسپانیایی',
	'es-419' => 'ئسپانیایی ئمریکا لاتین',
	'es-es' => 'ئسپانیایی ئوروٙپا',
	'es-mx' => 'ئسپانیایی مئکزیک',
	'et' => 'ئستونیایی',
	'eu' => 'باسکی',
	'fa' => 'فارسی',
	'fi' => 'فأنلاندی',
	'fil' => 'فیلیپینی',
	'fj' => 'فیجی',
	'fo' => 'فاروٙسی',
	'fr' => 'فآرانسئ ئی',
	'fr-ca' => 'فآرانسئ ئی کانادا',
	'fr-ch' => 'فآرانسئ ئی سوٙییس',
	'fy' => 'فئریسی أفتونئشین',
	'ga' => 'ئیرلأندی',
	'gag' => 'گاگائوز',
	'gl' => 'گالیسی',
	'gn' => 'گوٙآرانی',
	'gsw' => 'آلمانی سوٙئیسی',
	'gu' => 'گوجأراتی',
	'guz' => 'گوٙسی',
	'gv' => 'مانکس',
	'ha' => 'ھائوسا',
	'haw' => 'ھاڤایی',
	'he' => 'عئبری',
	'hi' => 'ھئنی',
	'hr' => 'کوروڤاتی',
	'hsb' => 'سوربی ڤارو',
	'ht' => 'ھاییتی',
	'hu' => 'مأجاری',
	'hy' => 'أرمأنی',
	'id' => 'أندونئزیایی',
	'ig' => 'ئیگبو',
	'ii' => 'سی چوان یی',
	'is' => 'ئیسلأندی',
	'it' => 'ئیتالیایی',
	'iu' => 'ئینوکتیتوٙت',
	'ja' => 'جاپوٙنی',
	'jgo' => 'نئگوٙمبا',
	'jmc' => 'ماچامئ',
	'jv' => 'جاڤئ یی',
	'ka' => 'گورجی',
	'kab' => 'کابیلئ',
	'kam' => 'کامبا',
	'kde' => 'ماکوٙندئ',
	'kea' => 'کاباردینو',
	'khq' => 'کی یورا چینی',
	'ki' => 'کیکیوٙ',
	'kk' => 'قأزاق',
	'kl' => 'کالالیسوٙت',
	'kln' => 'کالئجین',
	'km' => 'خئمئر',
	'kn' => 'کاناد',
	'ko' => 'کورئ یی',
	'koi' => 'کومی پئرمیاک',
	'kok' => 'کوٙنکانی',
	'ks' => 'کأشمیری',
	'ksb' => 'شامبالا',
	'ksf' => 'بافیا',
	'ku' => 'کوردی کورمانجی',
	'kw' => 'کورنیش',
	'ky' => 'قئرقیزی',
	'la' => 'لاتین',
	'lag' => 'لانگی',
	'lb' => 'لوٙکزامبوٙرگی',
	'lg' => 'گاندا',
	'lkt' => 'لاکوٙتا',
	'ln' => 'لینگالا',
	'lo' => 'لاو',
	'lrc' => 'لۊری شومالی',
	'lt' => 'لیتوڤانیایی',
	'lu' => 'لوٙبا کاتانگا',
	'luo' => 'لوٙ',
	'luy' => 'لوٙئیا',
	'lv' => 'لاتوڤیایی',
	'mas' => 'ماسایی',
	'mer' => 'مئرو',
	'mfe' => 'موٙریسی',
	'mg' => 'مالاگاشی',
	'mgh' => 'ماخوڤا میتو',
	'mgo' => 'مئتاٛ',
	'mi' => 'مائوری',
	'mk' => 'مأقدوٙنی',
	'ml' => 'مالایام',
	'mn' => 'موغولی',
	'moh' => 'موٙھاڤک',
	'mr' => 'مأراتی',
	'ms' => 'مالایی',
	'mt' => 'مالتی',
	'mua' => 'موٙندانگ',
	'my' => 'بئرمئ یی',
	'mzn' => 'مازأندأرانی',
	'naq' => 'ناما',
	'nb' => 'نورڤئجی بوٙکمال',
	'nd' => 'نئدئبئلئ شومالی',
	'nds' => 'آلمانی ھاری',
	'nds-nl' => 'آلمانی ھارگە جا',
	'ne' => 'نئپالی',
	'nl' => 'ھولأندی',
	'nl-be' => 'فئلاماندی',
	'nmg' => 'کئڤاسیوٙ',
	'nn' => 'نورڤئجی نینورسک',
	'nqo' => 'نئکوٙ',
	'nus' => 'نیوٙئر',
	'nyn' => 'نیان کوٙلئ',
	'om' => 'ئوروموٙ',
	'or' => 'ئوریا',
	'pa' => 'پأنجابی',
	'pl' => 'لأھئستانی',
	'ps' => 'پأشتوٙ',
	'pt' => 'پورتئغالی',
	'pt-br' => 'پورتئغالی بئرئزیل',
	'pt-pt' => 'پورتئغالی ئوروٙپایی',
	'qu' => 'کوچوٙا',
	'quc' => 'کیچی',
	'rm' => 'رومانش',
	'rn' => 'راندی',
	'ro' => 'رومانیایی',
	'ro-md' => 'رومانیایی مولداڤی',
	'rof' => 'رومبو',
	'ru' => 'روٙسی',
	'rw' => 'کینیاروآندا',
	'rwk' => 'رئڤا',
	'sa' => 'سانسکئریت',
	'saq' => 'سامبوٙروٙ',
	'sbp' => 'سانگوٙ',
	'sd' => 'سئندی',
	'sdh' => 'کوردی ھارگە',
	'se' => 'سامی شومالی',
	'seh' => 'سئنا',
	'ses' => 'کیارابورو سئنی',
	'sg' => 'سانگو',
	'shi' => 'تاچئلھیت',
	'si' => 'سینھالا',
	'sk' => 'ئسلوڤاکی',
	'sl' => 'ئسلوڤئنیایی',
	'sma' => 'سامی ھارگە',
	'smj' => 'لۉلئ سامی',
	'smn' => 'ئیناری سامی',
	'sms' => 'ئسکولت سامی',
	'sn' => 'شونا',
	'so' => 'سوٙمالی',
	'sq' => 'آلبانی',
	'sr' => 'سئربی',
	'su' => 'سوٙدانی',
	'sv' => 'سوٙئدی',
	'sw' => 'سأڤاحیلی',
	'swc' => 'سأڤاحیلی کونگو',
	'ta' => 'تامیل',
	'te' => 'تئلئگو',
	'teo' => 'تئسو',
	'tg' => 'تاجیکی',
	'th' => 'تایلأندی',
	'ti' => 'تیگرینیا',
	'tk' => 'تورکأمأنی',
	'to' => 'توٙنگان',
	'tr' => 'تورکی',
	'tt' => 'تاتار',
	'twq' => 'تاساڤاق',
	'tzm' => 'تامازیغ مینجایی',
	'ug' => 'ئویغوٙر',
	'uk' => 'ئوکراینی',
	'und' => 'زوٙن نادیار',
	'ur' => 'ئوردوٙ',
	'uz' => 'ئوزبأکی',
	'vai' => 'ڤای',
	'vi' => 'ڤییئتنامی',
	'vun' => 'ڤوٙنجوٙ',
	'wbp' => 'ڤارلپیری',
	'wo' => 'ڤولوف',
	'xh' => 'خوٙسا',
	'xog' => 'سوٙگا',
	'yo' => 'یوروبا',
	'zgh' => 'تامازیغ مأراکئشی',
	'zh' => 'چینی',
	'zh-hans' => 'چینی سادە بیە',
	'zh-hant' => 'چینی سونأتی',
	'zu' => 'زولو',
	'zxx' => 'بی نئشوٙ',
);

$currencyNames = array(
	'BRL' => 'رئال بئرئزیل',
	'CNY' => 'یوان چین',
	'EUR' => 'یورو',
	'GBP' => 'پوند بئریتانیا',
	'INR' => 'روٙپیه هئن',
	'JPY' => 'یئن جاپوٙن',
	'RUB' => 'روٙبل روٙسیه',
	'USD' => 'USD',
	'XXX' => 'پیل نادیار',
);

$currencySymbols = array(
	'BRL' => 'R$',
	'CNY' => 'CN¥',
	'EUR' => '€',
	'GBP' => '£',
	'INR' => '₹',
	'JPY' => 'JP¥',
	'RUB' => 'RUB',
	'USD' => 'US$',
);

$countryNames = array(
	'BR' => 'بئرئزیل',
	'CN' => 'چین',
	'DE' => 'آلمان',
	'FR' => 'فأرانسە',
	'GB' => 'بیریتانیا گأپ',
	'IN' => 'ھئن',
	'IT' => 'ئیتالیا',
	'JP' => 'جاپوٙن',
	'RU' => 'روٙسیە',
	'US' => 'ڤولاتیا یأکاگئرتە',
);

==> MediaWikiLanguageExtensionBundle-2017.01.tar.bz2: extensions/cldr/CldrNames/CldrNamesLrc.php <==
<?php

$languageNames = [
	'ab' => 'آذأربایئجانی',
	'af' => 'آفریکانس',
	'agq' => 'آقئم',
	'ak' => 'آکان',
	'am' => 'أمھأری',
	'ar' => 'أرأڤی',
	'ar-001' => 'عروی مدرن',
	'arn' => 'ماپوٙچئ',
	'as' => 'آسامی',
	'asa' => 'آسوٙ',
	'az' => 'آذأربایئجانی ھارگە',
	'az-arab' => 'آذأری ھارگە',
	'ba' => 'باشکیری',
	'be' => 'بئلاروٙسی',
	'bem' => 'بیما',
	'bez' => 'بئنا',
	'bg' => 'بولغاری',
	'bgn' => 'بألوٙچی أقتوٙنئشین',
	'bm' => 'بامبارا',
	'bn' => 'بأنگالی',
	'bo' => 'تأبأتی',
	'br' => 'بئرئتون',
	'brx' => 'بودو',
	'bs' => 'بوسنیایی',
	'ca' => 'کاتالان',
	'ce' => 'چئچئنی',
	'cgg' => 'چیگا',
	'chr' => 'چوروٙکی',
	'ckb' => 'کوردی سوٙرانی',
	'co' => 'کوریسکان',
	'cv' => 'چواشی',
	'cy' => 'ڤئلزی',
	'da' => 'دانمارکی',
	'dav' => 'تایتا',
	'de' => 'آلمانی',
	'de-at' => 'آلمانی ئوتریشی',
	'de-ch' => 'آلمانی سوٙییسی',
	'dje' => 'زارما',
	'dsb' => 'سوربی ھاری',
	'dua' => 'دوٙالا',
	'dyo' => 'جولا فوٙنیی',
	'dz' => 'زوٙنگخا',
	'ebu' => 'ئمبو',
	'ee' => 'ئڤئ',
	'el' => 'یوٙنانی',
	'en' => 'ئینگیلیسی',
	'en-au' => 'ئینگیلیسی ئوستارالیایی',
	'en-ca' => 'ئینگیلیسی کانادایی',
	'en-gb' => 'ئینگیلیسی بئریتانیایی',
	'en-us' => 'ئینگیلیسی ئمریکایی',
	'eo' => 'ئسپئرانتو',
	'es' => 'ئسپانیایی',
	'es-419' => 'ئسپانیایی ئمریکا لاتین',
	'es-es' => 'ئسپانیایی ئوروٙپا',
	'es-mx' => 'ئسپانیایی مئکزیک',
	'et' => 'ئستونیایی',
	'eu' => 'باسکی',
	'fa' => 'فارسی',
	'fi' => 'فأنلاندی',
	'fil' => 'فیلیپینی',
	'fj' => 'فیجی',
	'fo' => 'فاروٙسی',
	'fr' => 'فآرانسئ ئی',
	'fr-ca' => 'فآرانسئ ئی کانادا',
	'fr-ch' => 'فآرانسئ ئی سوٙییس',
	'fy' => 'فئریسی أفتونئشین',
	'ga' => 'ئیرلأندی',
	'gag' => 'گاگائوز',
	'gl' => 'گالیسی',
	'gn' => 'گوٙآرانی',
	'gsw' => 'آلمانی سوٙئیسی',
	'gu' => 'گوجأراتی',
	'guz' => 'گوٙسی',
	'gv' => 'مانکس',
	'ha' => 'ھائوسا',
	'haw' => 'ھاڤایی',
	'he' => 'عئبری',
	'hi' => 'ھئنی',
	'hr' => 'کوروڤاتی',
	'hsb' => 'سوربی ڤارو',
	'ht' => 'ھاییتی',
	'hu' => 'مأجاری',
	'hy' => 'أرمأنی',
	'id' => 'أندونئزیایی',
	'ig' => 'ئیگبو',
	'ii' => 'سی چوان یی',
	'is' => 'ئیسلأندی',
	'it' => 'ئیتالیایی',
	'iu' => 'ئینوکتیتوٙت',
	'ja' => 'جاپوٙنی',
	'jgo' => 'نئگوٙمبا',
	'jmc' => 'ماچامئ',
	'jv' => 'جاڤئ یی',
	'ka' => 'گورجی',
	'kab' => 'کابیلئ',
	'kam' => 'کامبا',
	'kde' => 'ماکوٙندئ',
	'kea' => 'کاباردینو',
	'khq' => 'کی یورا چینی',
	'ki' => 'کیکیوٙ',
	'kk' => 'قأزاق',
	'kl' => 'کالالیسوٙت',
	'kln' => 'کالئجین',
	'km' => 'خئمئر',
	'kn' => 'کاناد',
	'ko' => 'کورئ یی',
	'koi' => 'کومی پئرمیاک',
	'kok' => 'کوٙنکانی',
	'ks' => 'کأشمیری',
	'ksb' => 'شامبالا',
	'ksf' => 'بافیا',
	'ku' => 'کوردی کورمانجی',
	'kw' => 'کورنیش',
	'ky' => 'قئرقیزی',
	'la' => 'لاتین',
	'lag' => 'لانگی',
	'lb' => 'لوٙکزامبوٙرگی',
	'lg' => 'گاندا',
	'lkt' => 'لاکوٙتا',
	'ln' => 'لینگالا',
	'lo' => 'لاو',
	'lrc' => 'لۊری شومالی',
	'lt' => 'لیتوڤانیایی',
	'lu' => 'لوٙبا کاتانگا',
	'luo' => 'لوٙ',
	'luy' => 'لوٙئیا',
	'lv' => 'لاتوڤیایی',
	'mas' => 'ماسایی',
	'mer' => 'مئرو',
	'mfe' => 'موٙریسی',
	'mg' => 'مالاگاشی',
	'mgh' => 'ماخوڤا میتو',
	'mgo' => 'مئتاٛ',
	'mi' => 'مائوری',
	'mk' => 'مأقدوٙنی',
	'ml' => 'مالایام',
	'mn' => 'موغولی',
	'moh' => 'موٙھاڤک',
	'mr' => 'مأراتی',
	'ms' => 'مالایی',
	'mt' => 'مالتی',
	'mua' => 'موٙندانگ',
	'my' => 'بئرمئ یی',
	'mzn' => 'مازأندأرانی',
	'naq' => 'ناما',
	'nb' => 'نورڤئجی بوٙکمال',
	'nd' => 'نئدئبئلئ شومالی',
	'nds' => 'آلمانی ھاری',
	'nds-nl' => 'آلمانی ھارگە جا',
	'ne' => 'نئپالی',
	'nl' => 'ھولأندی',
	'nl-be' => 'فئلاماندی',
	'nmg' => 'کئڤاسیوٙ',
	'nn' => 'نورڤئجی نینورسک',
	'nqo' => 'نئکوٙ',
	'nus' => 'نیوٙئر',
	'nyn' => 'نیان کوٙلئ',
	'om' => 'ئوروموٙ',
	'or' => 'ئوریا',
	'pa' => 'پأنجابی',
	'pl' => 'لأھئستانی',
	'ps' => 'پأشتوٙ',
	'pt' => 'پورتئغالی',
	'pt-br' => 'پورتئغالی بئرئزیل',
	'pt-pt' => 'پورتئغالی ئوروٙپایی',
	'qu' => 'کوچوٙا',
	'quc' => 'کیچی',
	'rm' => 'رومانش',
	'rn' => 'راندی',
	'ro' => 'رومانیایی',
	'ro-md' => 'رومانیایی مولداڤی',
	'rof' => 'رومبو',
	'ru' => 'روٙسی',
	'rw' => 'کینیاروآندا',
	'rwk' => 'رئڤا',
	'sa' => 'سانسکئریت',
	'saq' => 'سامبوٙروٙ',
	'sbp' => 'سانگوٙ',
	'sd' => 'سئندی',
	'sdh' => 'کوردی ھارگە',
	'se' => 'سامی شومالی',
	'seh' => 'سئنا',
	'ses' => 'کیارابورو سئنی',
	'sg' => 'سانگو',
	'shi' => 'تاچئلھیت',
	'si' => 'سینھالا',
	'sk' => 'ئسلوڤاکی',
	'sl' => 'ئسلوڤئنیایی',
	'sma' => 'سامی ھارگە',
	'smj' => 'لۉلئ سامی',
	'smn' => 'ئیناری سامی',
	'sms' => 'ئسکولت سامی',
	'sn' => 'شونا',
	'so' => 'سوٙمالی',
	'sq' => 'آلبانی',
	'sr' => 'سئربی',
	'su' => 'سوٙدانی',
	'sv' => 'سوٙئدی',
	'sw' => 'سأڤاحیلی',
	'sw-cd' => 'سأڤاحیلی کونگو',
	'ta' => 'تامیل',
	'te' => 'تئلئگو',
	'teo' => 'تئسو',
	'tg' => 'تاجیکی',
	'th' => 'تایلأندی',
	'ti' => 'تیگرینیا',
	'tk' => 'تورکأمأنی',
	'to' => 'توٙنگان',
	'tr' => 'تورکی',
	'tt' => 'تاتار',
	'twq' => 'تاساڤاق',
	'tzm' => 'تامازیغ مینجایی',
	'ug' => 'ئویغوٙر',
	'uk' => 'ئوکراینی',
	'und' => 'زوٙن نادیار',
	'ur' => 'ئوردوٙ',
	'uz' => 'ئوزبأکی',
	'vai' => 'ڤای',
	'vi' => 'ڤییئتنامی',
	'vun' => 'ڤوٙنجوٙ',
	'wbp' => 'ڤارلپیری',
	'wo' => 'ڤولوف',
	'xh' => 'خوٙسا',
	'xog' => 'سوٙگا',
	'yo' => 'یوروبا',
	'zgh' => 'تامازیغ مأراکئشی',
	'zh' => 'چینی',
	'zh-hans' => 'چینی سادە بیە',
	'zh-hant' => 'چینی سونأتی',
	'zu' => 'زولو',
	'zxx' => 'بی نئشوٙ',
];

$currencyNames = [
	'BRL' => 'رئال بئرئزیل',
	'CNY' => 'یوان چین',
	'EUR' => 'یورو',
	'GBP' => 'پوند بئریتانیا',
	'INR' => 'روٙپیه هئن',
	'JPY' => 'یئن جاپوٙن',
	'RUB' => 'روٙبل روٙسیه',
	'USD' => 'USD',
	'XXX' => 'پیل نادیار',
];

$currencySymbols = [
	'BRL' => 'R$',
	'CNY' => 'CN¥',
	'EUR' => '€',
	'GBP' => '£',
	'INR' => '₹',
	'JPY' => 'JP¥',
	'RUB' => 'RUB',
	'USD' => 'US$',
];

$countryNames = [
	'BR' => 'بئرئزیل',
	'CN' => 'چین',
	'DE' => 'آلمان',
	'FR' => 'فأرانسە',
	'GB' => 'بیریتانیا گأپ',
	'IN' => 'ھئن',
	'IT' => 'ئیتالیا',
	'JP' => 'جاپوٙن',
	'RU' => 'روٙسیە',
	'US' => 'ڤولاتیا یأکاگئرتە',
];
